******
korona
******

|version| |travis| |coveralls| |license|

Korona helps you to generate HTML pages from the given inputs(HTML Tags and Attributes) without writing the HTML code.

Links
=====

- Project: https://github.com/bharadwajyarlagadda/korona
- Documentation: http://korona.readthedocs.io
- Pypi: https://pypi.python.org/pypi/korona
- TravisCI: https://travis-ci.org/bharadwajyarlagadda/korona

Features
========

- Supported on Python 2.7 and Python 3.3+
- With this package, you can avoid writing direct HTML code.

Quickstart
==========

Install using pip:

::

    pip install korona


.. |version| image:: https://img.shields.io/pypi/v/korona.svg?style=flat-square
    :target: https://pypi.python.org/pypi/korona/

.. |travis| image:: https://img.shields.io/travis/bharadwajyarlagadda/korona/master.svg?style=flat-square
    :target: https://travis-ci.org/bharadwajyarlagadda/korona

.. |coveralls| image:: https://img.shields.io/coveralls/bharadwajyarlagadda/korona/master.svg?style=flat-square
    :target: https://coveralls.io/r/bharadwajyarlagadda/korona

.. |license| image:: https://img.shields.io/pypi/l/korona.svg?style=flat-square
    :target: https://pypi.python.org/pypi/korona/
